==> jc-1.4.0.tar.gz: gnu/java/text/SentenceBreakIterator.h <==
// public class gnu.java.text.SentenceBreakIterator

// class file dependencies
// @dep_class 476c0dd5f88e2bbd gnu_java_text_BaseBreakIterator
// @dep_class e745c0a99b8cbc05 gnu_java_text_SentenceBreakIterator
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 44db16a713f84af5 java_text_BreakIterator

// header file dependencies
// @dep_header gnu_java_text_BaseBreakIterator

#include "gnu/java/text/BaseBreakIterator.h"

#ifndef _JC_gnu_java_text_SentenceBreakIterator_H_
#define _JC_gnu_java_text_SentenceBreakIterator_H_

// Forward structure declarations
struct _jc_gnu_java_text_SentenceBreakIterator$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_text_SentenceBreakIterator$sub_refs	_jc_gnu_java_text_SentenceBreakIterator$sub_refs;
typedef struct _jc_gnu_java_text_SentenceBreakIterator$sub_nonrefs	_jc_gnu_java_text_SentenceBreakIterator$sub_nonrefs;
typedef struct _jc_gnu_java_text_SentenceBreakIterator$refs	_jc_gnu_java_text_SentenceBreakIterator$refs;
typedef struct _jc_gnu_java_text_SentenceBreakIterator$nonrefs	_jc_gnu_java_text_SentenceBreakIterator$nonrefs;
typedef struct _jc_gnu_java_text_SentenceBreakIterator$object	_jc_gnu_java_text_SentenceBreakIterator$object;

typedef const struct _jc_gnu_java_text_SentenceBreakIterator$vmethods	_jc_gnu_java_text_SentenceBreakIterator$vmethods;
typedef const struct _jc_gnu_java_text_SentenceBreakIterator$vtable	_jc_gnu_java_text_SentenceBreakIterator$vtable;
typedef const struct _jc_gnu_java_text_SentenceBreakIterator$vtype	_jc_gnu_java_text_SentenceBreakIterator$vtype;

// Constructors
extern void _jc_gnu_java_text_SentenceBreakIterator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *);
extern void _jc_gnu_java_text_SentenceBreakIterator$method$_init$4e880cdaccdbf6d5(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *, struct _jc_gnu_java_text_SentenceBreakIterator$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_text_SentenceBreakIterator$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *);
extern jint _jc_gnu_java_text_SentenceBreakIterator$method$next$0a35667a0e69bb19(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *);
extern jint _jc_gnu_java_text_SentenceBreakIterator$method$previous$9ade62028ea90005(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *);
extern jint _jc_gnu_java_text_SentenceBreakIterator$method$previous__5finternal$6d3668530a2c7c0b(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_text_SentenceBreakIterator$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_gnu_java_text_SentenceBreakIterator$method_info$next$0a35667a0e69bb19;
extern _jc_method _jc_gnu_java_text_SentenceBreakIterator$method_info$previous$9ade62028ea90005;
extern _jc_method _jc_gnu_java_text_SentenceBreakIterator$method_info$previous__5finternal$6d3668530a2c7c0b;

// Virtual methods structure
struct _jc_gnu_java_text_SentenceBreakIterator$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *);
	jint	(*next$0a35667a0e69bb19)(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *);
	jint	(*previous$9ade62028ea90005)(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *);
	jint	(*previous__5finternal$6d3668530a2c7c0b)(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *);
};

// Vtable
struct _jc_gnu_java_text_SentenceBreakIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_BreakIterator$vmethods	java_text_BreakIterator;
	_jc_gnu_java_text_BaseBreakIterator$vmethods	gnu_java_text_BaseBreakIterator;
	_jc_gnu_java_text_SentenceBreakIterator$vmethods	gnu_java_text_SentenceBreakIterator;
};

// Vtype
struct _jc_gnu_java_text_SentenceBreakIterator$vtype {
	_jc_type			type;
	_jc_gnu_java_text_SentenceBreakIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_text_SentenceBreakIterator$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_text_SentenceBreakIterator$refs {
    _jc_gnu_java_text_SentenceBreakIterator$sub_refs	gnu_java_text_SentenceBreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_refs	gnu_java_text_BaseBreakIterator;
    _jc_java_text_BreakIterator$sub_refs	java_text_BreakIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_text_SentenceBreakIterator$sub_nonrefs {
	jint	period;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_text_SentenceBreakIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_BreakIterator$sub_nonrefs	java_text_BreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_nonrefs	gnu_java_text_BaseBreakIterator;
    _jc_gnu_java_text_SentenceBreakIterator$sub_nonrefs	gnu_java_text_SentenceBreakIterator;
};

// Object instance structure
struct _jc_gnu_java_text_SentenceBreakIterator$object {
	_jc_gnu_java_text_SentenceBreakIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_text_SentenceBreakIterator$vtype	*vtype;
	_jc_gnu_java_text_SentenceBreakIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_text_SentenceBreakIterator$vtype _jc_gnu_java_text_SentenceBreakIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_text_SentenceBreakIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_text_SentenceBreakIterator$class_object;

#endif	/* _JC_gnu_java_text_SentenceBreakIterator_H_ */

==> jc-1.4.6.tar.gz: gnu/java/text/SentenceBreakIterator.h <==
// public class gnu.java.text.SentenceBreakIterator

// class file dependencies
// @dep_class 476c0dd5f88e2bbd gnu_java_text_BaseBreakIterator
// @dep_class e745c0a99b8cbc05 gnu_java_text_SentenceBreakIterator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 44db16a713f84af5 java_text_BreakIterator

// header file dependencies
// @dep_header gnu_java_text_BaseBreakIterator

#include "gnu/java/text/BaseBreakIterator.h"

#ifndef _JC_gnu_java_text_SentenceBreakIterator_H_
#define _JC_gnu_java_text_SentenceBreakIterator_H_

// Forward structure declarations
struct _jc_gnu_java_text_SentenceBreakIterator$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_text_SentenceBreakIterator$sub_refs	_jc_gnu_java_text_SentenceBreakIterator$sub_refs;
typedef struct _jc_gnu_java_text_SentenceBreakIterator$sub_nonrefs	_jc_gnu_java_text_SentenceBreakIterator$sub_nonrefs;
typedef struct _jc_gnu_java_text_SentenceBreakIterator$refs	_jc_gnu_java_text_SentenceBreakIterator$refs;
typedef struct _jc_gnu_java_text_SentenceBreakIterator$nonrefs	_jc_gnu_java_text_SentenceBreakIterator$nonrefs;
typedef struct _jc_gnu_java_text_SentenceBreakIterator$object	_jc_gnu_java_text_SentenceBreakIterator$object;

typedef const struct _jc_gnu_java_text_SentenceBreakIterator$vmethods	_jc_gnu_java_text_SentenceBreakIterator$vmethods;
typedef const struct _jc_gnu_java_text_SentenceBreakIterator$vtable	_jc_gnu_java_text_SentenceBreakIterator$vtable;
typedef const struct _jc_gnu_java_text_SentenceBreakIterator$vtype	_jc_gnu_java_text_SentenceBreakIterator$vtype;

// Constructors
extern void _jc_gnu_java_text_SentenceBreakIterator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_text_SentenceBreakIterator$method$_init$4e880cdaccdbf6d5(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *, struct _jc_gnu_java_text_SentenceBreakIterator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_text_SentenceBreakIterator$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_text_SentenceBreakIterator$method$next$0a35667a0e69bb19(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_text_SentenceBreakIterator$method$previous$9ade62028ea90005(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_text_SentenceBreakIterator$method$previous__5finternal$6d3668530a2c7c0b(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_text_SentenceBreakIterator$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_gnu_java_text_SentenceBreakIterator$method_info$next$0a35667a0e69bb19;
extern _jc_method _jc_gnu_java_text_SentenceBreakIterator$method_info$previous$9ade62028ea90005;
extern _jc_method _jc_gnu_java_text_SentenceBreakIterator$method_info$previous__5finternal$6d3668530a2c7c0b;

// Virtual methods structure
struct _jc_gnu_java_text_SentenceBreakIterator$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *) _JC_JCNI_ATTR;
	jint	(*next$0a35667a0e69bb19)(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *) _JC_JCNI_ATTR;
	jint	(*previous$9ade62028ea90005)(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *) _JC_JCNI_ATTR;
	jint	(*previous__5finternal$6d3668530a2c7c0b)(_jc_env *, struct _jc_gnu_java_text_SentenceBreakIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_text_SentenceBreakIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_BreakIterator$vmethods	java_text_BreakIterator;
	_jc_gnu_java_text_BaseBreakIterator$vmethods	gnu_java_text_BaseBreakIterator;
	_jc_gnu_java_text_SentenceBreakIterator$vmethods	gnu_java_text_SentenceBreakIterator;
};

// Vtype
struct _jc_gnu_java_text_SentenceBreakIterator$vtype {
	_jc_type			type;
	_jc_gnu_java_text_SentenceBreakIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_text_SentenceBreakIterator$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_text_SentenceBreakIterator$refs {
    _jc_gnu_java_text_SentenceBreakIterator$sub_refs	gnu_java_text_SentenceBreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_refs	gnu_java_text_BaseBreakIterator;
    _jc_java_text_BreakIterator$sub_refs	java_text_BreakIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_text_SentenceBreakIterator$sub_nonrefs {
	jint	period;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_text_SentenceBreakIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_BreakIterator$sub_nonrefs	java_text_BreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_nonrefs	gnu_java_text_BaseBreakIterator;
    _jc_gnu_java_text_SentenceBreakIterator$sub_nonrefs	gnu_java_text_SentenceBreakIterator;
};

// Object instance structure
struct _jc_gnu_java_text_SentenceBreakIterator$object {
	_jc_gnu_java_text_SentenceBreakIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_text_SentenceBreakIterator$vtype	*vtype;
	_jc_gnu_java_text_SentenceBreakIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_text_SentenceBreakIterator$vtype _jc_gnu_java_text_SentenceBreakIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_text_SentenceBreakIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_text_SentenceBreakIterator$class_object;

#endif	/* _JC_gnu_java_text_SentenceBreakIterator_H_ */
